Change log
===========

0.0.2 - 15/10/2017
--------------------------------------------------------------------------------

Added
*******

#. Automatically inflate project meta data. One yehua command and typing a few
   questions are required before a complete project scaffolding
#. Automatically obtain setupmobans repo for previous task.
#. Automatically initialize package as git project and add all project files
   for the user to commit

Removed
********

#. Built-in template files are off-loaded to setupmobans, which are more frequently
   updated.

0.0.1 - 02/07/2017
--------------------------------------------------------------------------------

Initial release.
